from PropBank.Frameset import Frameset
import os


class FramesetList(object):

    __frames: list

    def __init__(self):
        """
        A constructor of FramesetList class which reads all frameset files inside the Predicates folder. For each
        file inside that folder, the constructor creates a Frameset and puts in inside the frames list.
        """
        self.__frames = []
        for r, d, f in os.walk("Predicates/"):
            for file in f:
                frameset = Frameset(os.path.join(r, file))
                self.__frames.append(frameset)

    def readFromXml(self, synSetId: str) -> dict:
        """
        readFromXmL method searches the Frameset with a given synSetId if there is a Frameset with the given synSet id,
        returns the arguments of that Frameset as a dictionary.

        PARAMETERS
        ----------
        synSetId : str
            Id of the searched Frameset

        RETURNS
        -------
        dict
            a dict containing the arguments of the searched Frameset
        """
        frameset = {}
        for f in self.__frames:
            if f.getId() == synSetId:
                for i in range(len(f.getFramesetArguments())):
                    framesetArgument = f.getFramesetArguments()[i]
                    frameset[framesetArgument.getArgumentType()] = framesetArgument.getDefinition()
        return frameset

    def frameExists(self, synSetId: str) -> bool:
        """
        frameExists method checks if there is a Frameset with the given synSet id.

        PARAMETERS
        ----------
        synSetId : str
            Id of the searched Frameset

        RETURNS
        -------
        bool
            true if the Frameset with the given id exists, false otherwise.
        """
        for f in self.__frames:
            if f.getId == synSetId:
                return True
        return False

    def getFrameSet(self, synSetId: str) -> Frameset:
        """
        getFrameSet method returns the Frameset with the given synSet id.

        PARAMETERS
        ----------
        synSetId : str
            Id of the searched Frameset

        RETURNS
        -------
        Frameset
            Frameset which has the given id.
        """
        for f in self.__frames:
            if f.getId == synSetId:
                return f
        return None

    def addFrameset(self, frameset: Frameset):
        """
        The addFrameset method takes a Frameset as input and adds it to the frames list.

        PARAMETERS
        ----------
        frameset : Frameset
            Frameset to be added
        """
        self.__frames.append(frameset)

    def getFrameset(self, index: int) -> Frameset:
        """
        The getFrameSet method returns the frameset at the given index.

        PARAMETERS
        ----------
        index : int
            Index of the frameset

        RETURNS
        -------
        Frameset
            Frameset at the given index.
        """
        return self.__frames[index]

    def size(self) -> int:
        """
        The size method returns the size of the frames list.

        RETURNS
        -------
        int
            the size of the frames list.
        """
        return len(self.__frames)



class Argument(object):

    __argumentType: str
    __id: str

    def __init__(self, argument: str):
        """
        A constructor of Argument class which takes argument string which is in the form of argumentType$id
        and parses this string into argumentType and id. If the argument string does not contain '$' then the
        constructor return a NONE type argument.

        PARAMETERS
        ----------
        argument : str
            Argument string containing the argumentType and id
        """
        if "$" in argument:
            self.__argumentType = argument[0:argument.index("$")]
            self.__id = argument[argument.index("$") + 1:]
        else:
            self.__argumentType = "NONE"

    def initWithId(self, argumentType: str, _id: str):
        """
        Another constructor of Argument class which takes argumentType and id as inputs and initializes corresponding 
        attributes

        PARAMETERS
        ----------
        argumentType : str 
            Type of the argument
        _id : str 
            Id of the argument
        """
        self.__argumentType = argumentType
        self.__id = _id

    def getArgumentType(self) -> str:
        """
        Accessor for argumentType.

        RETURNS
        -------
        str
            argumentType.
        """
        return self.__argumentType

    def getId(self) -> str:
        """
        Accessor for id.

        RETURNS
        -------
        str
            id.
        """
        return self.__id

    def __str__(self) -> str:
        """
        __str__ converts an Argument to a string. If the argumentType is "NONE" returns only "NONE", otherwise
        it returns argument string which is in the form of argumentType$id

        RETURNS
        -------
        str
            string form of argument
        """
        if self.__argumentType == "NONE":
            return self.__argumentType
        else:
            return self.__argumentType + "$" + self.__id



from setuptools import setup

setup(
    name='NlpToolkit-PropBank',
    version='1.0.12',
    packages=['PropBank'],
    url='https://github.com/olcaytaner/TurkishPropbank-Py',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='Turkish PropBank'
)



import os
import xml.etree.ElementTree
from collections import KeysView

from PropBank.Predicate import Predicate
from PropBank.RoleSet import RoleSet
from PropBank.Role import Role


class PredicateList(object):

    __list: dict

    def __init__(self):
        """
        A constructor of PredicateList class which reads all predicate files inside the 'Frames' folder. For each
        file inside that folder, the constructor creates a Predicate and puts in inside the list dictionary.
        """
        self.__list = {}
        for r, d, f in os.walk("Frames/"):
            for file in f:
                root = xml.etree.ElementTree.parse(os.path.join(r, file)).getroot()
                for predicate in root:
                    lemma = predicate.attrib["lemma"]
                    newPredicate = Predicate(lemma)
                    for roleSet in predicate:
                        _id = roleSet.attrib["id"]
                        name = roleSet.attrib["name"]
                        newRoleSet = RoleSet(_id, name)
                        for roles in roleSet:
                            for role in roles:
                                if "descr" in role.attrib:
                                    descr = role.attrib["descr"]
                                else:
                                    descr = ""
                                if "f" in role.attrib:
                                    f = role.attrib["f"]
                                else:
                                    f = ""
                                if "n" in role.attrib:
                                    n = role.attrib["n"]
                                else:
                                    n = ""
                                newRole = Role(descr, f, n)
                                newRoleSet.addRole(newRole)
                        newPredicate.addRoleSet(newRoleSet)
                    self.__list[lemma] = newPredicate

    def size(self):
        """
        The size method returns the number of predicates inside the list.

        RETURNS
        -------
        int
            the size of the list dict.
        """
        return len(self.__list)

    def getPredicate(self, lemma: str) -> Predicate:
        """
        getPredicate method returns the Predicate with the given lemma.

        PARAMETERS
        ----------
        lemma : str
            Lemma of the searched predicate

        RETURNS
        -------
        Predicate
            Predicate which has the given lemma.
        """
        return self.__list[lemma]

    def getLemmaList(self) -> KeysView:
        """
        The method returns all lemma in the predicate list.

        RETURNS
        -------
        dict
            All lemma in the predicate list.
        """
        return self.__list.keys()
